@@ -1,5 +1,5 @@
 #  ##### BEGIN GPL LICENSE BLOCK #####
-# 
+#
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -22,10 +22,11 @@ from . import view3d
 from . import socketutils
 from . import imageutils
 from . import app
+from . import colorutils
 
 print("""
 Python module PumpkinPy
 Owner: Spatial Innovations <https://github.com/Spatial-Innovations>
 Contributors:
     Patrick Huang <https://github.com/HuangPatrick16777216>
-    Arjun Sahlot <https://github.com/ArjunSahlot>""")
\ No newline at end of file
+    Arjun Sahlot <https://github.com/ArjunSahlot>""")
